pub struct TraceableBox(pub Box<dyn TraceableError + Send + Sync + 'static>);Expand description
A concrete, sized encapsulation of a dynamic TraceableError trait object.
This wrapper acts as a type-erased boundary. It enables seamless bidirectional ? operator
compatibility across dynamic crate boundaries, allowing concrete error enums (via thiserror)
and untyped conduits (anyhow) to nest inside each other without losing causal tracing history.
Example
use traceable_error::{TraceableError, TraceableBox};
fn produce_anyhow() -> anyhow::Result<()> {
Err(anyhow::anyhow!("root failure"))
}
// Seamlessly converts the anyhow::Error into a TraceableBox trait object via ?
fn consume_box() -> Result<(), TraceableBox> {
produce_anyhow()?;
Ok(())
}Tuple Fields
0: Box<dyn TraceableError + Send + Sync + 'static>Implementations
Sourceimpl TraceableBox
impl TraceableBox
pub fn layer_code(&self) -> String
pub fn chain_codes(&self) -> Vec<String>
pub fn diagnostic_code(&self) -> String